#!/usr/bin/env python

"""
This is a little script to help outputting universal coordinated time
dates from files in different languages and different formatting.
Usually the output will be used in a sed s/... command or from another
python script using regular expressions, but it also works directly
from commandline, emulating 'date -u' output. Possible 'public' calls
from other scripts are localize_time and localize_time_from_file. The
main section (run when the script is not imported from other scripts)
just shows an example and shouldn't be considered a standalone program.

License: this script is gift-ware, it's given to you freely as a gift.
You may use, modify, redistribute, and generally hack it about in any way
you like, and you do not have to give me anything in return. However, if
you like this script you are encouraged to thank me emailing me your
opinion about it, requests for more features, or directly diffs which
implement them. If you redistribute parts of this script or use it
somewhere successfully, it would be nice if you mentioned me somewhere
in the credits, but you are not required to do this.

Of course, I do not accept responsibility for any effects, adverse or
otherwise, that this code may have on you, your computer, your sanity,
your dog and anything else that you can think of.

Use it at your own risk.

Written by Grzegorz Adam Hankiewicz. Possible contact emails:
gradha@terra.es, gradha@users.sourceforge.net, gradha@iname.com.
Download this and other things from http://gradha.infierno.org.
"""

import time, os, stat, sys, string

default_format_string = "%(hour)02d:%(minute)02d, %(daynumber)d %(monthname)s %(year)d UTC"



def load_translation_text (localization_file):
   """
   load_translation_text (localization_file) -> twelve item list
   Internal helper for localize_time, opens a file and splits it's first line:
   if twelve words are found, they are returned. If there's any problem, the
   classical english month names are returned, all exceptions are catched.
   """
   try:
      file = open (localization_file, "rt")
      test = string.split (file.readline(), None, 12)
      file.close()
      return test[:12]
   except:
      return ["January", "February", "March", "April", "May", "June",
         "July", "August", "September", "October", "November", "December"]



def localize_time (time_in_seconds = 0, format = default_format_string, localization_file = ""):
   """
   localize_time (time_in_seconds, format, localization_file) -> string
   Returns the format string filled with time information according to
   time_in_seconds, which is ``time since the epoch'' (see python's
   time module documentation. localization_file can be blank, see
   load_translation_text's function documentation for information.
   """
   months = load_translation_text (localization_file)
   assert len (months) == 12
   tuple = time.gmtime (time_in_seconds)
   dic = {"hour": tuple[3], "minute": tuple[4], "daynumber":tuple[2],
      "monthname":months[tuple[1]-1], "year": tuple[0]}
   return "%s" % (format % (dic))

   

def localize_time_from_file (filename, format = default_format_string, localization_file = ""):
   """
   localize_time_from_file (filename, format, localization_file) -> string
   Wrapper around localize_time: time_in_seconds is extracted from the
   file's last modification time. localization_file can be blank, see
   load_translation_text's function documentation for information.
   """
   return localize_time (os.stat (filename)[stat.ST_MTIME], format, localization_file)


if __name__ == "__main__":
	print "This doesn't do anything alone. Please see example.py."

